==> accumulo-2.1.0-src.tar.gz: accumulo-2.1.0/server/monitor/src/main/java/org/apache/accumulo/monitor/rest/logs/DeadLoggerInformation.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.accumulo.monitor.rest.logs;

import jakarta.xml.bind.annotation.XmlAttribute;

/**
 * Stores dead logger information
 *
 * @since 2.0.0
 */
public class DeadLoggerInformation {

  // Variable names become JSON keys
  @XmlAttribute
  public String server;

  @XmlAttribute
  public long lastStatus;

  @XmlAttribute
  public String status;

  public DeadLoggerInformation() {}

  /**
   * Stores a new dead logger information
   *
   * @param server
   *          dead logger location
   * @param lastStatus
   *          previous status of the dead logger
   * @param status
   *          status of the dead logger
   */
  public DeadLoggerInformation(String server, long lastStatus, String status) {
    this.server = server;
    this.lastStatus = lastStatus;
    this.status = status;
  }
}

==> accumulo-3.0.0-src.tar.gz: accumulo-3.0.0/server/monitor/src/main/java/org/apache/accumulo/monitor/rest/logs/DeadLoggerInformation.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.accumulo.monitor.rest.logs;

import jakarta.xml.bind.annotation.XmlAttribute;

/**
 * Stores dead logger information
 *
 * @since 2.0.0
 */
public class DeadLoggerInformation {

  // Variable names become JSON keys
  @XmlAttribute
  public String server;

  @XmlAttribute
  public long lastStatus;

  @XmlAttribute
  public String status;

  public DeadLoggerInformation() {}

  /**
   * Stores a new dead logger information
   *
   * @param server dead logger location
   * @param lastStatus previous status of the dead logger
   * @param status status of the dead logger
   */
  public DeadLoggerInformation(String server, long lastStatus, String status) {
    this.server = server;
    this.lastStatus = lastStatus;
    this.status = status;
  }
}
